@@ -12,16 +12,13 @@ class networksettings:
 		i686_WIRELESS_OPTS = "C:\\python24\\pdaxrom\\misc\\wireless"
 		CFG_FILENAME = "network.cfg"
 	else:
-		WIRELESS_OPTS = "/etc/pcmcia/wireless.opts"
-		NETWORK_OPTS = "/etc/pcmcia/network.opts"
-		i686_NETWORK_OPTS = "/etc/sysconfig/network"
-		i686_WIRELESS_OPTS = "/etc/sysconfig/wireless"
+		CFG_PATH = "/etc/sysconfig/netconfig/"
 		CFG_FILENAME = os.environ['HOME'] + "/Choices/network.cfg"
 	
 	NOTINUPDATEMODE = True
 	
 	PROFILELIST = []
-	SETTING_NAME = "default"
+	SETTING_NAME = "none"
 	DELETE_PROFILE_NAME = ""
 	
 	OUTPUT_WIRELESS = ""
@@ -101,11 +98,11 @@ case "$ADDRESS" in
 
 
 	def __init__(self):
-		if (getpass.getuser().lower() != "root" and os.name != "nt"):
-			Warningdialog = gtk.MessageDialog(None,gtk.DIALOG_MODAL|gtk.DIALOG_DESTROY_WITH_PARENT,gtk.MESSAGE_WARNING,gtk.BUTTONS_OK,"You need to be root in order to run this program.")
-			Warningdialog.run()
-			Warningdialog.destroy()
-			sys.exit()
+#		if (getpass.getuser().lower() != "root" and os.name != "nt"):
+#			Warningdialog = gtk.MessageDialog(None,gtk.DIALOG_MODAL|gtk.DIALOG_DESTROY_WITH_PARENT,gtk.MESSAGE_WARNING,gtk.BUTTONS_OK,"You need to be root in order to run this program.")
+#			Warningdialog.run()
+#			Warningdialog.destroy()
+#			sys.exit()
 	        self.window = gtk.Window(gtk.WINDOW_TOPLEVEL)
 	        self.window.set_title("Network settings")
 	        self.window.set_border_width(4)
@@ -123,16 +120,16 @@ case "$ADDRESS" in
 
 		# Tabbed interface
 		self.profileframe = gtk.Frame()
-		label = gtk.Label("Network profiles")
+		label = gtk.Label("Network devices")
 		self.notebook.append_page(self.profileframe, label)
 	     	profilebox = gtk.VBox(gtk.FALSE, 5)
 		self.profileframe.add(profilebox)
 
-		tcpipframe = gtk.Frame()
+		self.tcpipframe = gtk.Frame()
 		label = gtk.Label("TCP/IP & DNS")
-		self.notebook.append_page(tcpipframe, label)
+		self.notebook.append_page(self.tcpipframe, label)
 	     	tcpipbox = gtk.VBox(gtk.FALSE, 5)
-		tcpipframe.add(tcpipbox)
+		self.tcpipframe.add(tcpipbox)
 
 		self.wirelessframe = gtk.Frame()
 		label = gtk.Label("Wireless")
@@ -141,7 +138,7 @@ case "$ADDRESS" in
 		self.wirelessframe.add(wirelessbox)
 
 # Profile start
-		profileloadframe = gtk.Frame("Profiles")
+		profileloadframe = gtk.Frame("Device")
 		profileloadframe.set_border_width(4)
 		profilebox.pack_start(profileloadframe, gtk.FALSE, gtk.FALSE, 5)
 		
@@ -151,8 +148,8 @@ case "$ADDRESS" in
 		hbox = gtk.HBox(gtk.FALSE, 5)
 		vbox.pack_start(hbox, gtk.FALSE, gtk.FALSE, 5)
 		
-		label = gtk.Label("Network type:")
-		hbox.pack_start(label, gtk.FALSE, gtk.FALSE, 5)
+		self.label_nt = gtk.Label("Network type:")
+		hbox.pack_start(self.label_nt, gtk.FALSE, gtk.FALSE, 5)
 	        self.connectiontype1 = gtk.RadioButton(None, "Normal")
 		self.connectiontype1.connect("clicked", self.set_network_type, False)
 		hbox.pack_start(self.connectiontype1, gtk.FALSE, gtk.FALSE, 5)
@@ -185,7 +182,7 @@ case "$ADDRESS" in
 		profile_remove.connect("clicked", self.delete_profile)
 
 		hintframe = gtk.Frame("Hint:")
-		label = gtk.Label("\nYou can select between the different profiles\nfrom terminal/shell using:\ncardctl scheme \"profilename\"\n")
+		label = gtk.Label("\nYou can look network device name from terminal/shell:\nifconfig -a\n")
 		hintframe.set_border_width(4)
 		hintframe.add(label)
 		profilebox.pack_start(hintframe, gtk.FALSE, gtk.FALSE, 5)
@@ -423,6 +420,13 @@ case "$ADDRESS" in
 
 	        self.profilecombo.connect('changed', self.changed_profile)
 	        self.window.show_all()
+
+		self.wirelessframe.set_sensitive(gtk.STATE_NORMAL)
+		self.tcpipframe.set_sensitive(gtk.STATE_NORMAL)
+		self.connectiontype1.set_sensitive(gtk.STATE_NORMAL)
+		self.connectiontype2.set_sensitive(gtk.STATE_NORMAL)
+		self.label_nt.set_sensitive(gtk.STATE_NORMAL)
+
 		if (self.is_wireless):
 			self.wirelessframe.show()
 		else:
@@ -588,6 +592,19 @@ case "$ADDRESS" in
 	def changed_profile(self, combobox):
 		model = combobox.get_model()
 		active = combobox.get_active()
+		if (model[active][0] == "none"):
+			self.wirelessframe.set_sensitive(gtk.STATE_NORMAL)
+			self.tcpipframe.set_sensitive(gtk.STATE_NORMAL)
+			self.connectiontype1.set_sensitive(gtk.STATE_NORMAL)
+			self.connectiontype2.set_sensitive(gtk.STATE_NORMAL)
+			self.label_nt.set_sensitive(gtk.STATE_NORMAL)
+		else:
+			self.tcpipframe.set_sensitive(gtk.STATE_INSENSITIVE)
+			self.wirelessframe.set_sensitive(gtk.STATE_INSENSITIVE)
+			self.connectiontype1.set_sensitive(gtk.STATE_INSENSITIVE)
+			self.connectiontype2.set_sensitive(gtk.STATE_INSENSITIVE)
+			self.label_nt.set_sensitive(gtk.STATE_INSENSITIVE)
+		
 		if (self.NOTINUPDATEMODE):
 			if (model[active][0] != self.SETTING_NAME):
 				self.load_profile(model[active][0])
@@ -603,7 +620,7 @@ case "$ADDRESS" in
 		return True
 
 	def rename_profile(self,widget):
-		if ("default" != self.find_profile_name()):
+		if ("none" != self.find_profile_name()):
 			# Add the new name to profile list and set the old to be the one to be deleted..
 			dialog = gtk.Dialog("Rename profile",self.window,gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT,(gtk.STOCK_OK, gtk.RESPONSE_ACCEPT,gtk.STOCK_CANCEL, gtk.RESPONSE_REJECT))
 			label = gtk.Label("Enter profile name..")
@@ -648,7 +665,7 @@ case "$ADDRESS" in
 
 
 	def delete_profile(self,widget):
-		if ("default" != self.find_profile_name()):
+		if ("none" != self.find_profile_name()):
 			Warningdialog = gtk.MessageDialog(self.window,gtk.DIALOG_MODAL|gtk.DIALOG_DESTROY_WITH_PARENT,gtk.MESSAGE_QUESTION,gtk.BUTTONS_YES_NO,"Are you sure you want to delete \""+self.SETTING_NAME+"\" profile?")
 			result = Warningdialog.run()
 			Warningdialog.destroy()
@@ -659,7 +676,7 @@ case "$ADDRESS" in
 				self.DELETE_PROFILE_NAME = ""
 				self.NOTINUPDATEMODE = True
 				self.profilecombo.remove_text(self.profilecombo.get_active())
-		elif ("default" == self.find_profile_name()):
+		elif ("none" == self.find_profile_name()):
 			Warningdialog = gtk.MessageDialog(self.window,gtk.DIALOG_MODAL|gtk.DIALOG_DESTROY_WITH_PARENT,gtk.MESSAGE_WARNING,gtk.BUTTONS_OK,"Can't delete the default profile.")
 			Warningdialog.run()
 			Warningdialog.destroy()
@@ -835,32 +852,7 @@ case "$ADDRESS" in
 			FD.close()
 		
 		self.make_output_files()
-
-	        if os.path.isdir("/etc/pcmcia"):
-			if (self.OUTPUT_WIRELESS <> ""):
-				f=open(self.WIRELESS_OPTS, 'w')
-				f.write(self.wireless_header + self.OUTPUT_WIRELESS.strip() + self.wireless_footer)
-				f.close()
-	
-			if (self.OUTPUT_NETWORK <> ""):
-				f=open(self.NETWORK_OPTS, 'w')
-				f.write(self.network_header + self.OUTPUT_NETWORK.strip() + self.network_footer)
-				f.close()
-
-
-		if (self.default_append_wireless <> ""):
-			f=open(self.i686_WIRELESS_OPTS, 'w')
-			self.default_append_wireless = self.default_append_wireless.replace(";;","")
-			self.default_append_wireless = self.default_append_wireless.replace("*,*,*,*|default,*,*,*)","")
-			f.write(self.default_append_wireless)
-			f.close()
-
-		if (self.default_append <> ""):
-			f=open(self.i686_NETWORK_OPTS, 'w')
-			self.default_append = self.default_append.replace(";;","")
-			self.default_append = self.default_append.replace("*,*,*,*|default,*,*,*)","")
-			f.write(self.default_append)
-			f.close()
+		
 		return True
 
 	def make_xml_save(self,net_node):
@@ -934,78 +926,70 @@ case "$ADDRESS" in
 				for tag in tags:
 					Network = tag.getElementsByTagName("Network")
 					for Networkset in Network:
-						if (Networkset.getAttribute("SETTINGNAME") == "default"):
-							returnstr_network = "*,*,*,*|"+Networkset.getAttribute("SETTINGNAME")+",*,*,*)\n"
-							returnstr_network += "\tINFO=\""+Networkset.getAttribute("SETTINGNAME")+"\""
-						else:
-							returnstr_network = Networkset.getAttribute("SETTINGNAME") + ",*,*,*)\n"
-							returnstr_network += "\tINFO=\""+Networkset.getAttribute("SETTINGNAME")+"\""
-						
-						returnstr_network += self.network_standard
+						returnstr_network = ""
 
 						if (Networkset.getAttribute("DHCP") == "1"):
-							returnstr_network += "\tDHCP=\"y\"\n"
-							returnstr_network += "\tIPADDR=\"\"\n"
-							returnstr_network += "\tNETMASK=\"\"\n"
-							returnstr_network += "\tGATEWAY=\"\"\n"
+							returnstr_network += "DHCP=\"y\"\n"
+							returnstr_network += "IPADDR=\"\"\n"
+							returnstr_network += "NETMASK=\"\"\n"
+							returnstr_network += "GATEWAY=\"\"\n"
 						else:
-							returnstr_network += "\tDHCP=\"n\"\n"
+							returnstr_network += "DHCP=\"n\"\n"
 							if (Networkset.getAttribute("IP_ADR") <> ""):
-								returnstr_network += "\tIPADDR=\""+Networkset.getAttribute("IP_ADR")+"\"\n"
+								returnstr_network += "IPADDR=\""+Networkset.getAttribute("IP_ADR")+"\"\n"
 							if (Networkset.getAttribute("SUBNET") <> ""):
-								returnstr_network += "\tNETMASK=\""+Networkset.getAttribute("SUBNET")+"\"\n"
+								returnstr_network += "NETMASK=\""+Networkset.getAttribute("SUBNET")+"\"\n"
 							if (Networkset.getAttribute("GATEWAY") <> ""):
-								returnstr_network += "\tGATEWAY=\""+Networkset.getAttribute("GATEWAY")+"\"\n"
+								returnstr_network += "GATEWAY=\""+Networkset.getAttribute("GATEWAY")+"\"\n"
 
 						if (Networkset.getAttribute("AUTO_DNS") == "1"):
-							returnstr_network += "\tDNS_1=\"\"\n"
-							returnstr_network += "\tDNS_2=\"\"\n"
-							returnstr_network += "\tDNS_3=\"\"\n"
+							returnstr_network += "DNS_1=\"\"\n"
+							returnstr_network += "DNS_2=\"\"\n"
+							returnstr_network += "DNS_3=\"\"\n"
 						else:
 							if (Networkset.getAttribute("DNS_1") <> ""):
-								returnstr_network += "\tDNS_1=\""+Networkset.getAttribute("DNS_1")+"\"\n"
+								returnstr_network += "DNS_1=\""+Networkset.getAttribute("DNS_1")+"\"\n"
 							if (Networkset.getAttribute("DNS_2") <> ""):
-								returnstr_network += "\tDNS_2=\""+Networkset.getAttribute("DNS_2")+"\"\n"
-							returnstr_network += "\tDNS_3=\"\"\n"
+								returnstr_network += "DNS_2=\""+Networkset.getAttribute("DNS_2")+"\"\n"
+							returnstr_network += "DNS_3=\"\"\n"
 
 						if (Networkset.getAttribute("DEF_DOMAIN") <> ""):
-							returnstr_network += "\tDOMAIN=\""+Networkset.getAttribute("DEF_DOMAIN")+"\"\n"
+							returnstr_network += "DOMAIN=\""+Networkset.getAttribute("DEF_DOMAIN")+"\"\n"
 						else:
-							returnstr_network += "\tDOMAIN=\"\"\n"
+							returnstr_network += "DOMAIN=\"\"\n"
 						
-						returnstr_network += "\t;;"
-						returnstr_network = returnstr_network.strip()+"\n\n"
+						##returnstr_network = returnstr_network.strip()+"\n\n"
 
-						if (Networkset.getAttribute("SETTINGNAME") == "default"):
+						if (Networkset.getAttribute("SETTINGNAME") == "none"):
 							self.default_append = returnstr_network
 						else:
 							self.OUTPUT_NETWORK += returnstr_network
 
-						if (Networkset.getAttribute("IS_WIRELESS") == "1" or Networkset.getAttribute("SETTINGNAME") == "default"):
-							if (Networkset.getAttribute("SETTINGNAME") == "default"):
-								returnstr_wireless = "*,*,*,*|default,*,*,*)\n"
-							else:
-								returnstr_wireless = Networkset.getAttribute("SETTINGNAME") + ",*,*,*)\n"
+						if (Networkset.getAttribute("IS_WIRELESS") == "1"):
+							returnstr_network += "WIRELESS=\"yes\"\n"
+
+						if (Networkset.getAttribute("IS_WIRELESS") == "1" or Networkset.getAttribute("SETTINGNAME") == "none"):
+							returnstr_wireless = ""
 							
 							if (Networkset.getAttribute("IS_WIRELESS") == "0"):
-								returnstr_wireless += "\tINFO=\""+Networkset.getAttribute("SETTINGNAME")+"\"\n"
-								returnstr_wireless += "\tESSID=\"any\"\n"
-								returnstr_wireless += "\tMODE=\"Managed\"\n"
-								returnstr_wireless += "\tKEY=\"\"\n"
+								returnstr_wireless += "INFO=\""+Networkset.getAttribute("SETTINGNAME")+"\"\n"
+								returnstr_wireless += "ESSID=\"any\"\n"
+								returnstr_wireless += "MODE=\"Managed\"\n"
+								returnstr_wireless += "KEY=\"\"\n"
 							else:
-								returnstr_wireless += "\tINFO=\""+Networkset.getAttribute("SETTINGNAME")+"\"\n"
+								returnstr_wireless += "INFO=\""+Networkset.getAttribute("SETTINGNAME")+"\"\n"
 								
 								if (Networkset.getAttribute("USE_ANY_ESSID") == "1"):
-									returnstr_wireless += "\tESSID=\"any\"\n"
-									returnstr_wireless += "\tMODE=\"Managed\"\n"
-									returnstr_wireless += "\tKEY=\"\"\n"
+									returnstr_wireless += "ESSID=\"any\"\n"
+									returnstr_wireless += "MODE=\"Managed\"\n"
+									returnstr_wireless += "KEY=\"\"\n"
 								else:
 									if (Networkset.getAttribute("ESSID") <> ""):
-										returnstr_wireless += "\tESSID=\"" + Networkset.getAttribute("ESSID") + "\"\n"
+										returnstr_wireless += "ESSID=\"" + Networkset.getAttribute("ESSID") + "\"\n"
 									if (Networkset.getAttribute("WMODE") <> ""):
-										returnstr_wireless += "\tMODE=\"" + Networkset.getAttribute("WMODE") + "\"\n"
+										returnstr_wireless += "MODE=\"" + Networkset.getAttribute("WMODE") + "\"\n"
 									if (int(Networkset.getAttribute("CHANNEL")) <> "" and int(Networkset.getAttribute("CHANNEL")) > 0):
-										returnstr_wireless += "\tCHANNEL=\"" + str(int(Networkset.getAttribute("CHANNEL"))) + "\"\n"
+										returnstr_wireless += "CHANNEL=\"" + str(int(Networkset.getAttribute("CHANNEL"))) + "\"\n"
 									if (Networkset.getAttribute("WEPKEY") <> "" and Networkset.getAttribute("WEPKEY_TYPE") <> "Disabled"):
 										if (Networkset.getAttribute("WEPKEY_TYPE") == "Text"):
 											key = Networkset.getAttribute("WEPKEY")
@@ -1015,22 +999,28 @@ case "$ADDRESS" in
 											#	hexkey += hex(ord(key[i-1:i]))[2:]
 											#	i = i + 1
 											# returnstr_wireless += "\tKEY=\"" + hexkey + "\"\n"
-											returnstr_wireless += "\tKEY=\"s:" + key + " "+ Networkset.getAttribute("WEP_AUTHTYPE") +"\"\n"
+											returnstr_wireless += "KEY=\"s:" + key + " "+ Networkset.getAttribute("WEP_AUTHTYPE") +"\"\n"
 										else:
-											returnstr_wireless += "\tKEY=\"" + Networkset.getAttribute("WEPKEY") + " "+ Networkset.getAttribute("WEP_AUTHTYPE") +"\"\n"
+											returnstr_wireless += "KEY=\"" + Networkset.getAttribute("WEPKEY") + " "+ Networkset.getAttribute("WEP_AUTHTYPE") +"\"\n"
 									else:
-										returnstr_wireless += "\tKEY=\"\"\n"
+										returnstr_wireless += "KEY=\"\"\n"
 								
 								if (Networkset.getAttribute("POWER") == "on"):
-									returnstr_wireless += "\tPOWER=\"on\"\n"
+									returnstr_wireless += "POWER=\"on\"\n"
 							
-							returnstr_wireless += "\t;;"
-							returnstr_wireless = returnstr_wireless.strip() + "\n\n"
+							#returnstr_wireless = returnstr_wireless.strip() + "\n\n"
 							
-							if (Networkset.getAttribute("SETTINGNAME") == "default"):
+							if (Networkset.getAttribute("SETTINGNAME") == "none"):
 								self.default_append_wireless = returnstr_wireless
 							else:
 								self.OUTPUT_WIRELESS += returnstr_wireless
+
+							returnstr_network += returnstr_wireless
+
+						f=open("/etc/sysconfig/netconfig/"+Networkset.getAttribute("SETTINGNAME")+".conf", 'w')
+						f.write(returnstr_network)
+						f.close()
+						
 				print self.OUTPUT_WIRELESS
 				if (self.default_append != ""):
 					self.OUTPUT_NETWORK += self.default_append
@@ -1065,15 +1055,16 @@ case "$ADDRESS" in
 		return True
 
 	def close_and_update(self,widget):
-		if (self.save_prefs() == False):
-			return False
-		else:
-			os.system("/sbin/cardctl eject")
-			os.system("/bin/sleep 1")
-			os.system("/sbin/cardctl scheme " + self.SETTING_NAME + " >/dev/null 2>&1")
-			os.system("/bin/sleep 1")
-			os.system("/sbin/cardctl insert")
-			gtk.main_quit()
+		self.save_prefs()
+		#if (self.save_prefs() == False):
+		#	return False
+		#else:
+		#	os.system("/sbin/cardctl eject")
+		#	os.system("/bin/sleep 1")
+		#	os.system("/sbin/cardctl scheme " + self.SETTING_NAME + " >/dev/null 2>&1")
+		#	os.system("/bin/sleep 1")
+		#	os.system("/sbin/cardctl insert")
+		gtk.main_quit()
 
 	def main(self):
         	gtk.main()
